@@ -79,6 +79,7 @@ private:
     void _q_toggleWindowState();
     void _q_showMinimized();
     void _q_onTopWindowMotifHintsChanged(quint32 winId);
+    void _q_closeWindow();
 
 #ifndef QT_NO_MENU
     void _q_addDefaultMenuItems();
@@ -354,7 +355,7 @@ void DTitlebarPrivate::init()
     q->setFocusPolicy(Qt::StrongFocus);
 
     auto noTitlebarEnabled = []{
-        if (qEnvironmentVariable("DDE_CURRENT_COMPOSITOR") == "TreeLand") {
+        if (DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::IsWaylandPlatform)) {
             return true;
         }
 
@@ -431,7 +432,8 @@ void DTitlebarPrivate::updateFullscreen()
 void DTitlebarPrivate::updateButtonsState(Qt::WindowFlags type)
 {
     D_Q(DTitlebar);
-    bool useDXcb = DPlatformWindowHandle::isEnabledDXcb(targetWindow()) || qEnvironmentVariable("DDE_CURRENT_COMPOSITOR") == "TreeLand";
+    bool useDXcb = DPlatformWindowHandle::isEnabledDXcb(targetWindow()) ||
+                   DGuiApplicationHelper::testAttribute(DGuiApplicationHelper::IsWaylandPlatform);
     bool isFullscreen = targetWindow()->windowState().testFlag(Qt::WindowFullScreen);
 
 //    bool forceShow = !useDXcb;
@@ -571,6 +573,13 @@ void DTitlebarPrivate::_q_toggleWindowState()
     }
 }
 
+void DTitlebarPrivate::_q_closeWindow()
+{
+    if (targetWindow()->windowHandle()) {
+        targetWindow()->windowHandle()->close();
+    }
+}
+
 void DTitlebarPrivate::_q_showMinimized()
 {
     targetWindow()->showMinimized();
@@ -1532,7 +1541,7 @@ void DTitlebar::setVisible(bool visible)
         connect(d->maxButton, SIGNAL(clicked()), this, SLOT(_q_toggleWindowState()), Qt::UniqueConnection);
         connect(this, SIGNAL(doubleClicked()), this, SLOT(_q_toggleWindowState()), Qt::UniqueConnection);
         connect(d->minButton, SIGNAL(clicked()), this, SLOT(_q_showMinimized()), Qt::UniqueConnection);
-        connect(d->closeButton, &DWindowCloseButton::clicked, d->targetWindow(), &QWidget::close, Qt::UniqueConnection);
+        connect(d->closeButton, SIGNAL(clicked()), this, SLOT(_q_closeWindow()), Qt::UniqueConnection);
 
         d->updateButtonsState(d->targetWindow()->windowFlags());
     } else {
